﻿using Couchbase;
using Couchbase.Configuration.Client;
using Couchbase.Lite;
using Couchbase.Lite.Auth;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Timers;

namespace JsonObjectCreator
{
    class Program
    {
        const string DB_NAME = "batch-test";
        const string TAG = "batch-test";
        static Database db;
        private static readonly Cluster Cluster = new Cluster();

        static void Main(string[] args)
        {
            try
            {
                db = Couchbase.Lite.Manager.SharedInstance.GetDatabase(DB_NAME);
            }
            catch (Exception e)
            {
                Console.WriteLine("{0}: Error getting database: {1}", TAG, e.Message);
                return;
            }

            StartReplicationsWithAuth();
            UploadData();
            Console.ReadLine();
        }

        static Uri CreateSyncUri()
        {
            Uri syncUri = null;
            string scheme = "http";
            string host = "172.16.1.15";
            int port = 4984;
            string dbName = "batch-test";
            try
            {
                var uriBuilder = new UriBuilder(scheme, host, port, dbName);
                syncUri = uriBuilder.Uri;
            }
            catch (UriFormatException e)
            {
                Console.WriteLine("{0}: Cannot create sync uri = {1}", TAG, e.Message);
            }
            return syncUri;
        }

        static string CreateDocument(Dictionary<string, object> obj)
        {
            var doc = db.CreateDocument();
            string docId = doc.Id;

            Dictionary<string, object> channels = new Dictionary<string, object>();
            obj.Add("channels", "Manura2");
            //obj.Add("type", "segment");

            //doc.PutProperties(channels);

            var props = obj;

            try
            {
                doc.PutProperties(props);
                //Console.WriteLine("{0}: doc written to database with ID = {1}", TAG, doc.Id);
            }
            catch (Exception e)
            {
                Console.WriteLine("{0}: Error putting properties to Couchbase Lite database = {1}", TAG, e.Message);
            }
            return docId;
        }

        static void UploadData()
        {
            string json = File.ReadAllText("Json2.json");
            var samples = JsonConvert.DeserializeObject<List<Dictionary<string, object>>>(json);
            int offset = 0;
            int limit = 400;
            //foreach (var sample in samples)
            //{
            //    for (int i = offset; i <= offset + limit; i++)
            //    {
            //        CreateDocument(samples[i]);
            //        Thread.Sleep(200);
            //    }
            //    Console.WriteLine("docs written to database from:{0} to:{1}", offset, offset+limit);
            //    Thread.Sleep(200000);
            //    offset += limit;
            //}

            CreateDocument(samples[0]);
            Console.ReadLine();
        }


        static void StartReplicationsWithAuth()
        {
            List<string> channelList = new List<string>();
            channelList.Add("Manura2");
            Replication pull = db.CreatePullReplication(CreateSyncUri());
            Replication push = db.CreatePushReplication(CreateSyncUri());
            var authenticator = AuthenticatorFactory.CreateBasicAuthenticator("couchbase_user", "mobile");
            pull.Authenticator = authenticator;
            push.Authenticator = authenticator;
            pull.Continuous = true;
            push.Continuous = true;
            pull.Start();
            push.Start();
            pull.Channels = channelList;
            push.Changed += Push_Changed;
            pull.Changed += Pull_Changed;
        }

        static private void Pull_Changed(object sender, ReplicationChangeEventArgs e)
        {

        }

        static private void Push_Changed(object sender, ReplicationChangeEventArgs e)
        {

        }
    }
}
